package App::upf;

our $DATE = '2020-04-29'; # DATE
our $VERSION = '0.050'; # VERSION

use 5.010001;

1;
# ABSTRACT: CLI interface for Unix::Passwd::File

__END__

=pod

=encoding UTF-8

=head1 NAME

App::upf - CLI interface for Unix::Passwd::File

=head1 VERSION

This document describes version 0.050 of App::upf (from Perl distribution App-upf), released on 2020-04-29.

=head1 SYNOPSIS

See L<upf>.

=head1 DESCRIPTION

This distribution includes L<upf>, a single CLI scripts with subcommands.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-upf>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-upf>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-upf>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Unix::Passwd::File>

L<App::UpfUtils>, where each function in Unix::Passwd::File has its own CLI
script instead of a single CLI program for all the functions like C<upf>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
